@@ -299,7 +299,10 @@ void LXQt::Wallet::setTranslationLanguage(const QString &language)
         QCoreApplication::installTranslator([&]()
         {
             auto e = new QTranslator();
-            e->load(l, TRANSLATIONS_PATH);
+	    auto m = e->load(l, TRANSLATIONS_PATH);
+	    if (!m){
+		    //???
+	    }
             return e;
         }());
     }
