@@ -56,13 +56,10 @@ int zuluCryptEXECloseVolume( const char * dev,const char * mapping_name,uid_t ui
 	 struct stat xt ;
 	 const char * mapper ;
 
-	 int r ;
-
 	 zuluCryptSecurityGainElevatedPrivileges() ;
 
-	 r = zuluCryptDeviceHasAgivenFileSystem( dev,zuluCryptBitLockerType() ) ;
-
-	 if( r == 1 ){
+	 if( zuluCryptDeviceHasAgivenFileSystem( dev,zuluCryptBitLockerType() ) &&
+			 zuluCryptDeviceManagedByDislocker( dev,uid ) ){
 
 		 p = zuluCryptBitLockerFullMapperPath( uid,dev ) ;
 
@@ -72,10 +69,10 @@ int zuluCryptEXECloseVolume( const char * dev,const char * mapping_name,uid_t ui
 
 		 zuluCryptSecurityDropElevatedPrivileges() ;
 
-		if( i != 0 ){
+		 if( i != 0 ){
 
-			 return zuluExit( 1,p ) ;
-		}
+			  return zuluExit( 1,p ) ;
+		 }
 	 }else{
 		 zuluCryptSecurityDropElevatedPrivileges() ;
 
@@ -106,13 +103,8 @@ int zuluCryptEXECloseVolume( const char * dev,const char * mapping_name,uid_t ui
 
 	 zuluCryptSecurityGainElevatedPrivileges() ;
 
-	 /*
-	  * zuluCryptCloseVolume() is defined in ../lib/close_volume.c
-	  *
-	  * zuluCryptReuseMountPoint() is defined in create_mount_point.c
-	  */
+	 if( zuluCryptIsDislockerMapperPath( StringContent( p ) ) ){
 
-	 if( r == 1 ){
 		 if( zuluCryptReuseMountPoint() ){
 
 			 st = zuluCryptBitLockerlock( p,NULL ) ;
