@@ -45,21 +45,19 @@ public:
 	explicit createfile( QWidget *,std::function< void( const QString& ) > ) ;
 	~createfile() ;
 signals :
-	void sendProgress( int ) ;
-public slots:
-	void warnAboutRandomData( int ) ;
-	void HideUI( void ) ;
-	void showUI( void ) ;
-	void pbOpenFolder( void ) ;
-	void pbCancel( void ) ;
-	void pbCreate( void ) ;
-private slots:
-	void setProgress( int ) ;
-	void fileTextChange( QString ) ;
+	void sendProgress( QString,QString,QString,QString,int ) ;
 private:
+	void warnAboutRandomData( int ) ;
+	void HideUI() ;
+	void showUI() ;
+	void pbOpenFolder() ;
+	void pbCancel() ;
+	void pbCreate() ;
+	void setProgress( QString,QString,QString,QString,int ) ;
+	void fileTextChange( QString ) ;
 	void createFile( const QString&,qint64 ) ;
-	void enableAll( void ) ;
-	void disableAll( void ) ;
+	void enableAll() ;
+	void disableAll() ;
 	void closeEvent( QCloseEvent * ) ;
 	bool eventFilter( QObject * watched,QEvent * event ) ;
 	Ui::createfile * m_ui ;
