@@ -58,16 +58,62 @@ createvolume::createvolume( QWidget * parent ) : QDialog( parent ),m_ui( new Ui:
 	m_ui->lineEditIterationNumber->setVisible( false ) ;
 	m_ui->labelIterationNumber->setVisible( false ) ;
 
-	connect( m_ui->pbOpenKeyFile,SIGNAL( clicked() ),this,SLOT( pbOpenKeyFile() ) ) ;
-	connect( m_ui->pbCreate,SIGNAL( clicked() ),this,SLOT( pbCreateClicked() ) ) ;
-	connect( m_ui->pbCancel,SIGNAL( clicked() ),this,SLOT( pbCancelClicked() ) ) ;
-	connect( m_ui->cbNormalVolume,SIGNAL( activated( int ) ),this,SLOT( cbNormalVolume( int ) ) ) ;
-	connect( m_ui->cbHiddenVolume,SIGNAL( activated( int ) ),this,SLOT( cbHiddenVolume( int ) ) ) ;
-	connect( m_ui->comboBoxVolumeType,SIGNAL( currentIndexChanged( int ) ),this,SLOT( volumeType( int ) ) ) ;
-	connect( m_ui->lineEditPassphrase1,SIGNAL( textChanged( QString ) ),this,SLOT( keyChanged_0( QString ) ) ) ;
-	connect( m_ui->lineEditHiddenKey,SIGNAL( textChanged( QString ) ),this,SLOT( keyChanged_1( QString ) ) ) ;
-	connect( m_ui->pbHiddenKeyFile,SIGNAL( clicked() ),this,SLOT( pbOpenHiddenKeyFile() ) ) ;
-	connect( m_ui->comboBoxVolumeType,SIGNAL( activated( int ) ),this,SLOT( setOptions( int ) ) ) ;
+	m_ui->groupBoxLUKS2Options->setVisible( false ) ;
+	m_ui->labelLUKS2Options->setVisible( false ) ;
+
+	connect( m_ui->pbLuks2Set,&QPushButton::clicked,[ this ](){
+
+		m_ui->groupBoxLUKS2Options->setVisible( false ) ;
+		m_ui->labelLUKS2Options->setVisible( false ) ;
+	} ) ;
+
+	connect( m_ui->pbLUKS2Options,&QPushButton::clicked,[ this ](){
+
+		m_showingLuks2AdvanceOptions = true ;
+		m_ui->groupBoxLUKS2Options->setVisible( true ) ;
+		m_ui->labelLUKS2Options->setVisible( true ) ;
+	} ) ;
+
+	connect( m_ui->pbLuks2Cancel,&QPushButton::clicked,[ this ](){
+
+		this->luks2Cancel() ;
+	} ) ;
+
+	auto m = static_cast< void ( QComboBox::* )( int ) >( &QComboBox::currentIndexChanged ) ;
+
+	connect( m_ui->cbLuks2Pbkdf,m,[ this ]( int s ){
+
+		if( s == 2 ){
+
+			m_ui->lineEditLuks2MaxMemory->clear() ;
+			m_ui->lineEditLuks2ParallelThreads->clear() ;
+
+			m_ui->lineEditLuks2MaxMemory->setEnabled( false ) ;
+			m_ui->lineEditLuks2ParallelThreads->setEnabled( false ) ;
+		}else{
+			m_ui->lineEditLuks2MaxMemory->setEnabled( true ) ;
+			m_ui->lineEditLuks2ParallelThreads->setEnabled( true ) ;
+		}
+	} ) ;
+
+#ifdef CRYPT_LUKS2
+	m_ui->cbLuks2AllowDiscard->setEnabled( true ) ;
+#else
+	m_ui->cbLuks2AllowDiscard->setEnabled( false ) ;
+#endif
+	auto act = static_cast< void( QComboBox::* )( int )>( &QComboBox::activated ) ;
+	auto aaa = static_cast< void( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ) ;
+
+	connect( m_ui->pbOpenKeyFile,&QPushButton::clicked,this,&createvolume::pbOpenKeyFile ) ;
+	connect( m_ui->pbCreate,&QPushButton::clicked,this,&createvolume::pbCreateClicked ) ;
+	connect( m_ui->pbCancel,&QPushButton::clicked,this,&createvolume::pbCancelClicked ) ;
+	connect( m_ui->cbNormalVolume,act,this,&createvolume::cbNormalVolume ) ;
+	connect( m_ui->cbHiddenVolume,act,this,&createvolume::cbHiddenVolume ) ;
+	connect( m_ui->comboBoxVolumeType,aaa,this,&createvolume::volumeType ) ;
+	connect( m_ui->lineEditPassphrase1,&QLineEdit::textChanged,this,&createvolume::keyChanged_0 ) ;
+	connect( m_ui->lineEditHiddenKey,&QLineEdit::textChanged,this,&createvolume::keyChanged_1 ) ;
+	connect( m_ui->pbHiddenKeyFile,&QPushButton::clicked,this,&createvolume::pbOpenHiddenKeyFile ) ;
+	connect( m_ui->comboBoxVolumeType,act,this,&createvolume::setOptions ) ;
 
         this->installEventFilter( this ) ;
 
@@ -83,10 +129,12 @@ createvolume::createvolume( QWidget * parent ) : QDialog( parent ),m_ui( new Ui:
 	m_ui->cbNormalVolume->addItem( tr( "Key" ) ) ;
 	m_ui->cbNormalVolume->addItem( tr( "KeyFile" ) ) ;
 	m_ui->cbNormalVolume->addItem( tr( "Key+KeyFile" ) ) ;
+	m_ui->cbNormalVolume->addItem( tr( "YubiKey Challenge/Response" ) ) ;
 
 	m_ui->cbHiddenVolume->addItem( tr( "Key" ) ) ;
 	m_ui->cbHiddenVolume->addItem( tr( "KeyFile" ) ) ;
 	m_ui->cbHiddenVolume->addItem( tr( "Key+KeyFile" ) ) ;
+	m_ui->cbHiddenVolume->addItem( tr( "YubiKey Challenge/Response" ) ) ;
 
 	m_veraCryptWarning.setWarningLabel( m_ui->veraCryptWarning ) ;
 
@@ -179,10 +227,12 @@ void createvolume::volumeType( int s )
 	m_ui->cbNormalVolume->addItem( tr( "Key" ) ) ;
 	m_ui->cbNormalVolume->addItem( tr( "KeyFile" ) ) ;
 	m_ui->cbNormalVolume->addItem( tr( "Key+KeyFile" ) ) ;
+	m_ui->cbNormalVolume->addItem( tr( "YubiKey Challenge/Response" ) ) ;
 
 	m_ui->cbHiddenVolume->addItem( tr( "Key" ) ) ;
 	m_ui->cbHiddenVolume->addItem( tr( "KeyFile" ) ) ;
 	m_ui->cbHiddenVolume->addItem( tr( "Key+KeyFile" ) ) ;
+	m_ui->cbHiddenVolume->addItem( tr( "YubiKey Challenge/Response" ) ) ;
 
 	auto _enableHidden = [ this ](){
 
@@ -315,9 +365,14 @@ void createvolume::closeEvent( QCloseEvent * e )
 {
 	e->ignore() ;
 
-	if( m_isWindowClosable ){
+	if( m_showingLuks2AdvanceOptions ){
 
-		this->pbCancelClicked() ;
+		this->luks2Cancel() ;
+	}else{
+		if( m_isWindowClosable ){
+
+			this->pbCancelClicked() ;
+		}
 	}
 }
 
@@ -345,8 +400,6 @@ void createvolume::eraseDataPartition()
 
 			}else if( r == 1 ){
 
-				;
-
 			}else if( r == 2 ){
 
 				erasedevice::instance( this ).ShowUI( m_ui->lineEditVolumePath->text() ) ;
@@ -403,10 +456,12 @@ void createvolume::setOptions( int e )
 
 	auto luksSelected = _luks() ;
 
-	m_ui->lineEditIterationNumber->setVisible( luksSelected ) ;
-	m_ui->labelIterationNumber->setVisible( luksSelected ) ;
-	m_ui->lineEditIterationNumber->clear() ;
-
+#ifdef CRYPT_LUKS2
+	auto type = m_ui->comboBoxVolumeType->currentIndex() ;
+	m_ui->pbLUKS2Options->setEnabled( type == createvolume::luks2_external_header || type == createvolume::luks2 ) ;
+#else
+	m_ui->pbLUKS2Options->setEnabled( false ) ;
+#endif
 	if( _plain_dmcrypt() ){
 
 		/*
@@ -607,6 +662,22 @@ void createvolume::tcryptGui( bool e )
 	} ) ;
 }
 
+void createvolume::luks2Cancel()
+{
+	m_showingLuks2AdvanceOptions = false ;
+	m_ui->groupBoxLUKS2Options->setVisible( false ) ;
+	m_ui->labelLUKS2Options->setVisible( false ) ;
+
+	m_ui->lineEditLuks2ForcedIteration->clear() ;
+	m_ui->lineEditLuks2UnlockingTime->clear() ;
+	m_ui->lineEditLuks2ParallelThreads->clear() ;
+	m_ui->lineEditLuks2MaxMemory->clear() ;
+	m_ui->lineLEdituks2Label->clear() ;
+	m_ui->lineEditLuks2SubSystem->clear() ;
+	m_ui->cbLuks2Pbkdf->setCurrentIndex( 0 ) ;
+	m_ui->cbLuks2AllowDiscard->setChecked( false ) ;
+}
+
 void createvolume::cbNormalVolume( int r )
 {
 	this->setWindowTitle( tr( "Create A New Volume" ) ) ;
@@ -667,6 +738,9 @@ void createvolume::cbNormalVolume( int r )
 				}
 			}
 		} ) ;
+	}else if( r == 3 ){
+
+		_set_key_ui() ;
 	}else{
 		m_ui->pbOpenKeyFile->setEnabled( false ) ;
 		m_ui->lineEditPassphrase1->clear() ;
@@ -742,6 +816,9 @@ void createvolume::cbHiddenVolume( int r )
 				}
 			}
 		} ) ;
+	} else if( r == 3 ){
+
+		_set_key_ui() ;
 	}else{
 		m_ui->pbHiddenKeyFile->setEnabled( false ) ;
 		m_ui->lineEditHiddenKey->clear() ;
@@ -779,7 +856,7 @@ void createvolume::enableAll()
 	m_ui->labelRepeatPassPhrase->setEnabled( true ) ;
 	m_ui->lineEditPassphrase1->setEnabled( true ) ;
 
-	if( m_ui->cbNormalVolume->currentIndex() == 0 ){
+	if( m_ui->cbNormalVolume->currentIndex() == 0 || m_ui->cbNormalVolume->currentIndex() == 3 ){
 
 		m_ui->lineEditPassPhrase2->setEnabled( true ) ;
 	}
@@ -830,10 +907,16 @@ void createvolume::enableAll()
 		m_ui->pbHiddenKeyFile->setEnabled(  m_ui->cbHiddenVolume->currentIndex() == 1 ) ;
 		m_ui->lineEditHiddenKey1->setEnabled(  m_ui->cbHiddenVolume->currentIndex() != 1 ) ;
 	}
+
+	if( m_ui->comboBoxVolumeType->currentText().startsWith( "LUKS2" ) ){
+
+		m_ui->pbLUKS2Options->setEnabled( true ) ;
+	}
 }
 
 void createvolume::disableAll()
 {
+	m_ui->pbLUKS2Options->setEnabled( false ) ;
 	m_ui->lineEditIterationNumber->setEnabled( false ) ;
 	m_ui->labelIterationNumber->setEnabled( false ) ;
 	m_ui->label_2->setEnabled( false ) ;
@@ -970,12 +1053,36 @@ void createvolume::pbCreateClicked()
 			source = "-f" ;
 			passphrase_1 = utility::resolvePath( passphrase_1 ).replace( "\"","\"\"\"" ) ;
 		}
-	}else{
+	}else if( r == 2 ){
+
 		source = "-f" ;
 
 		passphrase_1 = utility::keyPath() + "-2" ;
 
 		utility::keySend( passphrase_1,m_key ) ;
+
+	}else if( r == 3 ){
+
+		if( passphrase_1.isEmpty() ){
+
+			return 	msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
+		}
+		if( passphrase_1 != passphrase_2 ){
+
+			return 	msg.ShowUIOK( tr( "ERROR!" ),tr( "Passphrases do not match" ) ) ;
+		}
+
+		auto m = utility::yubiKey( passphrase_1 ) ;
+
+		if( m.has_value() ){
+
+			source = "-f" ;
+			passphrase_1 = utility::keyPath() + "-2" ;
+
+			utility::keySend( passphrase_1,m.value() ) ;
+		}else{
+			return msg.ShowUIOK( tr( "ERROR" ),tr( "Failed To Locate Or Run Yubikey's \"ykchalresp\" Program." ) ) ;
+		}
 	}
 
 	switch( type ){
@@ -1052,12 +1159,58 @@ void createvolume::pbCreateClicked()
 			g += "." + e ;
 		}
 	}else{
-		auto m = m_ui->lineEditIterationNumber->text() ;
+		auto forcedIterations = m_ui->lineEditLuks2ForcedIteration->text() ;
+		auto unlockingTime    = m_ui->lineEditLuks2UnlockingTime->text() ;
+		auto maxThreads       = m_ui->lineEditLuks2ParallelThreads->text() ;
+		auto maxMemory        = m_ui->lineEditLuks2MaxMemory->text() ;
+		auto label            = m_ui->lineLEdituks2Label->text() ;
+		auto subsystem        = m_ui->lineEditLuks2SubSystem->text() ;
+		auto pbkdf            = m_ui->cbLuks2Pbkdf->currentText() ;
 
-		if( !m.isEmpty() ){
+		QString integrity = "null" ;
 
-			g += "." + m ;
+		if( label.isEmpty() ){
+
+			label = "null" ;
 		}
+
+		if( subsystem.isEmpty() ){
+
+			subsystem = "null" ;
+		}
+
+		if( unlockingTime.isEmpty() ){
+
+			unlockingTime = "-1" ;
+		}
+
+		if( forcedIterations.isEmpty() ){
+
+			forcedIterations = "-1" ;
+		}
+
+		if( maxThreads.isEmpty() ){
+
+			maxThreads = "-1" ;
+		}
+
+		if( maxMemory.isEmpty() ){
+
+			maxMemory = "-1" ;
+		}
+
+		auto allowDiscard = [ this ](){
+
+			if( m_ui->cbLuks2AllowDiscard->isChecked() ){
+
+				return "1" ;
+			}else{
+				return "0" ;
+			}
+		}() ;
+
+		QString m = ".%1.%2.%3.%4.%5.%6.%7.%8.%9" ;
+		g += m.arg( unlockingTime,forcedIterations,integrity,pbkdf,maxMemory,maxThreads,label,subsystem,allowDiscard ) ;
 	}
 
 	volumePath.replace( "\"","\"\"\"" ) ;
@@ -1075,21 +1228,50 @@ void createvolume::pbCreateClicked()
 
 		auto x = m_ui->lineEditHiddenKey->text() ;
 
-		decltype( x ) y ;
+		QString y ;
 
 		auto k = m_ui->cbHiddenVolume->currentIndex() ;
 
 		if( k == 0 ){
 
+			if( x != m_ui->lineEditHiddenKey1->text() ){
+
+				return msg.ShowUIOK( tr( "ERROR!" ),tr( "Passphrases do not match" ) ) ;
+			}
+
 			y = utility::keyPath() + "-1" ;
 			utility::keySend( y,x ) ;
 
 		}else if( k == 1 ){
 
 			y = utility::resolvePath( x ).replace( "\"","\"\"\"" ) ;
-		}else{
+
+		}else if( k == 2 ){
+
 			y = utility::keyPath() + "-1" ;
 			utility::keySend( y,m_hiddenKey ) ;
+
+		}else if( k == 3 ){
+
+			if( x.isEmpty() ){
+
+				return 	msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
+			}
+
+			if( x != m_ui->lineEditHiddenKey1->text() ){
+
+				return msg.ShowUIOK( tr( "ERROR!" ),tr( "Passphrases do not match" ) ) ;
+			}
+
+			auto m = utility::yubiKey( x ) ;
+
+			if( m.has_value() ){
+
+				y = utility::keyPath() + "-1" ;
+				utility::keySend( y,m.value() ) ;
+			}else{
+				return msg.ShowUIOK( tr( "ERROR" ),tr( "Failed To Locate Or Run Yubikey's \"ykchalresp\" Program." ) ) ;
+			}
 		}
 
 		auto r = m_ui->lineEditHiddenSize->text().toULongLong() ;
@@ -1205,6 +1387,11 @@ void createvolume::taskFinished( const utility::Task& e )
 		x += tr( "\nCreating a backup of the \"%1\" volume header is strongly advised.\nPlease read documentation on why this is important." ).arg( m_volumeType ) ;
 	}
 
+	auto _err = [ & ](){
+
+		return tr( "Failed to create a volume" ) + "\n\n" + e.stdError() ;
+	} ;
+
 	switch ( e.exitCode() ){
 		case 0 : msg.ShowUIOK( tr( "SUCCESS!" ),x ) ;
 		return this->HideUI() ;
@@ -1230,7 +1417,7 @@ only root user or members of group zulucrypt can do that" ) ) ;										break
 		case 19: msg.ShowUIOK( tr( "ERROR!" ),tr( "Can not get passphrase in silent mode" ) ) ;					break  ;
 		case 20: msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient memory to hold passphrase" ) ) ;				break  ;
 		case 21: msg.ShowUIOK( tr( "ERROR!" ),tr( "Passphrases do not match") ) ;						break  ;
-		case 22: msg.ShowUIOK( tr( "ERROR!" ),tr( "Failed to create a volume" ) ) ;						break  ;
+		case 22: msg.ShowUIOK( tr( "ERROR!" ),_err() ) ;						break  ;
 		case 23: msg.ShowUIOK( tr( "ERROR!" ),tr( "Wrong argument detected for tcrypt volume" ) ) ;				break  ;
 		case 110:msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not find any partition with the presented UUID" ) ) ;			break  ;
 		default: msg.ShowUIOK( tr( "ERROR!" ),tr( "Error Code: %1\n--\nStdOut: %2\n--\nStdError: %3").arg( QString::number( e.exitCode() ),QString( e.stdError() ),QString( e.stdOut() ) ) ) ;
