@@ -43,23 +43,22 @@ public:
 	}
 	explicit erasedevice( QWidget * parent = 0 ) ;
 	~erasedevice() ;
-	void ShowUI( void ) ;
+	void ShowUI() ;
 	void ShowUI( const QString& ) ;
-	void HideUI( void ) ;
+	void HideUI() ;
 signals:
 	void complete( QString ) ;
-	void sendProgress( int ) ;
-private slots:
-	void enableAll( void ) ;
-	void disableAll( void ) ;
-	void pbStart( void ) ;
-	void pbCancel( void ) ;
-	void pbFile( void ) ;
-	void pbPartition( void ) ;
-	void setProgress( int ) ;
+	void sendProgress( QString,QString,QString,QString,int ) ;
+private:
+	void enableAll() ;
+	void disableAll() ;
+	void pbStart() ;
+	void pbCancel() ;
+	void pbFile() ;
+	void pbPartition() ;
+	void setProgress( QString,QString,QString,QString,int ) ;
 	void setPath( QString ) ;
 	void taskResult( int ) ;
-private:
 	void closeEvent( QCloseEvent * ) ;
 	bool eventFilter( QObject * watched,QEvent * event ) ;
 	Ui::erasedevice * m_ui ;
@@ -67,6 +66,8 @@ private:
 	std::atomic_bool m_exit ;
 	bool m_running ;
 	utility::label m_label ;
+	QString m_total_time ;
+	QString m_average_speed ;
 };
 
 #endif // ERASEDEVICE_H
