@@ -34,7 +34,6 @@ Task::future< void >& favorites2::deleteKey( secrets::wallet& wallet,const QStri
 	return Task::run( [ &wallet,id ](){
 
 		wallet->deleteKey( id ) ;
-		wallet->deleteKey( id + COMMENT ) ;
 	} ) ;
 }
 
@@ -44,7 +43,7 @@ Task::future< bool >& favorites2::addKey( secrets::wallet& wallet,
 {
 	return Task::run( [ &wallet,id,key ](){
 
-		if( wallet->addKey( id,key ) ){
+		if( wallet->addKey( id,key.toUtf8() ) ){
 
 			return true ;
 		}else{
@@ -84,23 +83,6 @@ favorites2::favorites2( QWidget * parent,
 
 	m_ui->tableWidget->setColumnWidth( 0,400 ) ;
 
-	connect( m_ui->cbAutoMountAtStartUp,&QCheckBox::toggled,[ this ]( bool e ){
-
-		m_settings.autoMountFavoritesOnStartUp( e ) ;
-	} ) ;
-
-	connect( m_ui->cbAllowExternalToolsToReadPasswords,&QCheckBox::toggled,[]( bool ){
-
-	} ) ;
-
-	connect( m_ui->cbAutoMountWhenAvailable,&QCheckBox::toggled,[]( bool ){
-
-	} ) ;
-
-	connect( m_ui->cbShowMountDialogWhenAutoMounting,&QCheckBox::toggled,[]( bool ){
-
-	} ) ;
-
 	connect( m_ui->tableWidget,&QTableWidget::customContextMenuRequested,[ this ]( QPoint s ){
 
 		Q_UNUSED( s )
@@ -143,6 +125,31 @@ favorites2::favorites2( QWidget * parent,
 
 	m_ui->pbFile->setIcon( QIcon( ":/file.png" ) ) ;
 	m_ui->pbPartition->setIcon( QIcon( ":/partition.png" ) ) ;
+	m_ui->pbFolder->setIcon( QIcon( ":/folder.png" ) ) ;
+
+	connect( m_ui->pbVolumePathFromFileSystem,&QPushButton::clicked,[ this ](){
+
+		auto e = this->getExistingFile( tr( "Path To An Encrypted Volume" ) ) ;
+
+		if( !e.isEmpty() ){
+
+			m_ui->lineEditVolumePath->setText( utility::pathToUUID( e ) ) ;
+		}
+	} ) ;
+
+	connect( m_ui->pbFolder,&QPushButton::clicked,[ this ](){
+
+		auto e = this->getExistingFolder( tr( "Path To An Encrypted Volume" ) ) ;
+
+		if( !e.isEmpty() ){
+
+			m_ui->lineEditVolumeID->setText( e ) ;
+
+			auto a = utility::split( e,'/' ).last() ;
+
+			m_ui->lineEditMountPath->setText( a ) ;
+		}
+	} ) ;
 
 	connect( m_ui->pbFile,&QPushButton::clicked,[ this ](){
 
@@ -152,7 +159,7 @@ favorites2::favorites2( QWidget * parent,
 
 			m_ui->lineEditVolumeID->setText( e ) ;
 
-			auto a = utility::split( m_ui->lineEditVolumeID->text(),'/' ).last() ;
+			auto a = utility::split( e,'/' ).last() ;
 
 			m_ui->lineEditMountPath->setText( a ) ;
 		}
@@ -256,12 +263,8 @@ favorites2::favorites2( QWidget * parent,
 
 		m_ui->rbKWallet->setChecked( true ) ;
 	}else{
-		m_ui->label_22->setEnabled( false ) ;
-		m_ui->pbChangeWalletPassword->setEnabled( false ) ;
-
-		m_ui->label_22->setText( tr( "Not Applicable" ) ) ;
-
 		m_ui->rbNone->setChecked( true ) ;
+		this->nobackendSet() ;
 	}
 
 	connect( m_ui->rbInternalWallet,&QRadioButton::toggled,[ this ]( bool e ){
@@ -309,13 +312,12 @@ favorites2::favorites2( QWidget * parent,
 		}
 	} ) ;
 
-	connect( m_ui->rbNone,&QRadioButton::toggled,[ this ](){
+	connect( m_ui->rbNone,&QRadioButton::toggled,[ this ]( bool e ){
 
-		m_ui->label_22->setText( tr( "Not Applicable" ) ) ;
-		m_ui->label_22->setEnabled( false ) ;
-		m_ui->pbChangeWalletPassword->setEnabled( false ) ;
-		this->setControlsAvailability( false,true ) ;
-		m_settings.autoMountBackEnd( settings::walletBackEnd() ) ;
+		if( e ){
+
+			this->nobackendSet() ;
+		}
 	} ) ;
 
 	connect( m_ui->pbClose,&QPushButton::clicked,[ this ](){
@@ -407,6 +409,15 @@ favorites2::~favorites2()
 	delete m_ui ;
 }
 
+void favorites2::nobackendSet()
+{
+	m_ui->label_22->setText( tr( "Not Applicable" ) ) ;
+	m_ui->label_22->setEnabled( false ) ;
+	m_ui->pbChangeWalletPassword->setEnabled( false ) ;
+	this->setControlsAvailability( false,true ) ;
+	m_settings.autoMountBackEnd( settings::walletBackEnd() ) ;
+}
+
 void favorites2::setCommand( QLineEdit * lineEdit )
 {
 	auto path = this->getExistingFile( tr( "Select A Command Executable" ) ) ;
@@ -424,6 +435,10 @@ void favorites2::addkeyToWallet()
 
 	if( a.isEmpty() || b.isEmpty() ){
 
+		m_ui->labelPassword->setText( tr( "Atleast One Required Field Is Empty" ) ) ;
+		m_ui->labelPassword->setVisible( true ) ;
+		m_ui->pbVisiblePassword->setVisible( true ) ;
+
 		return ;
 	}
 
@@ -468,7 +483,7 @@ QStringList favorites2::readAllKeys()
 
 	for( const auto& it : s ){
 
-		if( !it.endsWith( "-SiriKali_Comment_ID" ) ){
+		if( !it.endsWith( COMMENT ) ){
 
 			a.append( it ) ;
 		}
@@ -598,6 +613,7 @@ void favorites2::setControlsAvailability( bool e,bool m )
 	m_ui->lineEditPassword->setEnabled( e ) ;
 	m_ui->pbVolumePathFromFavorites->setEnabled( e ) ;
 	m_ui->cbShowPassword->setEnabled( e ) ;
+	m_ui->pbVolumePathFromFileSystem->setEnabled( e ) ;
 }
 
 void favorites2::tabChanged( int index )
@@ -629,7 +645,9 @@ void favorites2::tabChanged( int index )
 
 			connect( m,&QMenu::triggered,[ this ]( QAction * ac ){
 
-				m_ui->lineEditVolumePath->setText( ac->objectName() ) ;
+				auto m = ac->objectName() ;
+
+				m_ui->lineEditVolumePath->setText( utility::pathToUUID( m ) ) ;
 			} ) ;
 
 			m_ui->pbVolumePathFromFavorites->setMenu( m ) ;
@@ -737,6 +755,23 @@ void favorites2::HideUI()
 	this->deleteLater() ;
 }
 
+QString favorites2::getExistingFolder( const QString& r )
+{
+	auto e = QFileDialog::getExistingDirectory( this,r,QDir::homePath() ) ;
+
+	while( true ){
+
+		if( e.endsWith( '/' ) ){
+
+			e.truncate( e.length() - 1 ) ;
+		}else{
+			break ;
+		}
+	}
+
+	return e ;
+}
+
 QString favorites2::getExistingFile( const QString& r )
 {
 	auto e = QFileDialog::getOpenFileName( this,r,QDir::homePath() ) ;
@@ -756,20 +791,10 @@ QString favorites2::getExistingFile( const QString& r )
 
 void favorites2::ShowUI()
 {
-	//m_ui->lineEditMountPath->setText( m_settings.mountPath() ) ;
-
 	m_ui->tabWidget->setCurrentIndex( 0 ) ;
 
 	m_ui->tableWidget->setFocus() ;
 
-	//m_ui->cbAllowExternalToolsToReadPasswords->setChecked( m_settings.allowExternalToolsToReadPasswords() ) ;
-
-	//m_ui->cbAutoMountAtStartUp->setChecked( m_settings.autoMountFavoritesOnStartUp() ) ;
-
-	//m_ui->cbShowMountDialogWhenAutoMounting->setChecked( m_settings.showMountDialogWhenAutoMounting() ) ;
-
-	//m_ui->cbShowFavoriteListOnContextMenu->setChecked( m_settings.showFavoritesInContextMenu() ) ;
-
 	this->show() ;
 	this->raise() ;
 	this->activateWindow() ;
