@@ -75,6 +75,12 @@
 
 namespace utility
 {
+	template< typename Sender,typename Signal,typename Receiver,typename Slot>
+	void connect( Sender sender,Signal signal,Receiver receiver,Slot slot )
+	{
+		QObject::connect( sender,signal,receiver,slot,Qt::QueuedConnection ) ;
+	}
+
 	class label
 	{
 	public:
@@ -328,7 +334,66 @@ namespace utility
 
 	bool libCryptSetupLibraryNotFound() ;
 	int startApplication( const char * appName,std::function<int()> ) ;
-	void startApplication( QObject *,const char * ) ;
+
+	class invokeMethodImp : public QObject
+	{
+		Q_OBJECT
+	public:
+		void run()
+		{
+			emit start() ;
+
+			this->deleteLater() ;
+		}
+	signals:
+		void start() ;
+	} ;
+
+	class invokeMethodImp1 : public QObject
+	{
+		Q_OBJECT
+	public:
+		template< typename Function >
+		invokeMethodImp1( Function f ) : m_function( std::move( f ) )
+		{
+			auto m = Qt::QueuedConnection ;
+			connect( this,&invokeMethodImp1::start,this,&invokeMethodImp1::run,m ) ;
+			emit start() ;
+		}
+		void run()
+		{
+			m_function() ;
+			this->deleteLater() ;
+		}
+	signals:
+		void start() ;
+	private:
+		std::function< void() > m_function ;
+	} ;
+
+	template< typename ReceiverObject,
+		  typename Method,
+		  typename std::enable_if< std::is_member_function_pointer< Method >::value,int >::type = 0 >
+	void invokeMethod( ReceiverObject obj,Method method )
+	{
+		auto m = new invokeMethodImp() ;
+
+		QObject::connect( m,&invokeMethodImp::start,obj,method,Qt::QueuedConnection ) ;
+
+		m->run() ;
+
+		//QTimer::singleShot( 0,obj,method ) ;
+	}
+
+	template< typename ReceiverObject,
+		  typename Function,
+		  typename std::enable_if< !std::is_member_function_pointer< Function >::value,int >::type = 0 >
+	void invokeMethod( ReceiverObject obj,Function function )
+	{
+		Q_UNUSED( obj )
+		new invokeMethodImp1( std::move( function ) ) ;
+		//QTimer::singleShot( 0,obj,std::move( function ) ) ;
+	}
 
 	wallet getKey( LXQt::Wallet::Wallet&,const QString& keyID,
 		       const QString& app = QString() ) ;
@@ -388,7 +453,13 @@ namespace utility
 	bool pathExists( const QString& ) ;
 	bool canCreateFile( const QString& ) ;
 	bool useZuluPolkit( void ) ;
-	void startHelperExecutable( QObject *,const QString&,const QString&,const char *,const char * ) ;
+	struct startHelperStatus
+	{
+		std::function< void( bool,QString ) > success ;
+		std::function< void() > error ;
+	};
+
+	void startHelper( QObject *,const QString&,const QString&,startHelperStatus ) ;
 	void setDebugWindow( debugWindow * w ) ;
 	QString deviceIDToPartitionID( const QString& ) ;
 	QString fileManager( void ) ;
@@ -412,6 +483,8 @@ namespace utility
 	QString shareMountPointToolTip( void ) ;
 	QString shareMountPointToolTip( const QString& ) ;
 	QString sharedMountPointPath( const QString& ) ;
+	QString defaultPlugin( void ) ;
+	void setDefaultPlugin( const QString& ) ;
 	bool pathPointsToAFile( const QString& ) ;
 	bool pathPointsToAFolder( const QString& ) ;
 	bool configDirectoriesAreNotWritable( QWidget * ) ;
@@ -436,6 +509,7 @@ namespace utility
 	QStringList directoryList( const QString& ) ;
 	QStringList plainDmCryptOptions( void ) ;
 	QStringList supportedFileSystems( void ) ;
+	QString KWalletDefaultName( void ) ;
 	bool userHasGoodVersionOfWhirlpool( void ) ;
 	void licenseInfo( QWidget * ) ;
 	void showTrayIcon( QAction *,QSystemTrayIcon&,bool = true ) ;
@@ -446,6 +520,7 @@ namespace utility
 	void mountWithSharedMountPoint( bool ) ;
 	bool platformIsLinux( void ) ;
 	bool platformIsOSX( void ) ;
+	QString pathToUUID( const QString& path ) ;
 	QStringList executableSearchPaths( void ) ;
 	QString executableSearchPaths( const QString& ) ;
 	QString helperSocketPath( void ) ;
@@ -489,7 +564,7 @@ namespace utility
 	utility::array_t getWindowDimensions( const QString& application ) ;
 	void setWindowDimensions( const QString& application,const std::initializer_list<int>& ) ;
 
-	void createPlugInMenu( QMenu *,const QString&,const QString&,const QString&,bool ) ;
+	void addPluginsToMenu( QMenu& ) ;
 
 	int pluginKey( QWidget *,QByteArray *,const QString& ) ;
 
