@@ -23,6 +23,10 @@
 
 int main( int argc,char * argv[] )
 {
+	QSettings m( "zuluCrypt","zuluMount" ) ;
+
+	utility::setSettingsObject( &m ) ;
+
 	utility::setHDPI( "zuluMount" ) ;
 
 	QApplication a( argc,argv ) ;
@@ -31,7 +35,7 @@ int main( int argc,char * argv[] )
 
 		zuluMount e ;
 
-		utility::startApplication( &e,"Show" ) ;
+		utility::invokeMethod( &e,&zuluMount::Show ) ;
 
 		return a.exec() ;
 	} ) ;
